@@ -145,4 +145,52 @@ def erase_classifier(filename):
     filename: str
     """
     if os.path.exists(filename):
-        os.remove(filename)
\ No newline at end of file
+        os.remove(filename)
+
+
+def train_classifier_from_image_folders(classifier, features, **kwargs):
+    """Train any classifier from pairs or tuples of image folders.
+
+    When passing multiple folders for the training, it is necessary that
+    the images in these folders have identical filenames. For example,
+    to train a ObjectSegmenter, you need to pass two folders where the
+    images are organized like this:
+
+    * folder/
+      * images/
+        * image1.tif
+        * image2.tif
+        * image3.tif
+      * masks/
+        * image1.tif
+        * image2.tif
+        * image3.tif
+
+    Parameters
+    ----------
+    classifier: APOC classifier
+        e.g. PixelClassifier, ObjectClassifier, ObjectSegmenter, ProbabilityMapper
+    features: str
+        list of features, space separated
+    kwargs
+        depends on the classifier. See the classifier's train() function for details
+    """
+    import os
+    from skimage.io import imread
+
+    any_folder = kwargs[list(kwargs.keys())[0]]
+    file_list = os.listdir(any_folder)
+    continue_training = False
+    for filename in file_list:
+
+        # assemble parameters for training
+        kwargs_to_pass = {
+            'features': features,
+            'continue_training': continue_training
+        }
+        for key, value in kwargs.items():
+            kwargs_to_pass[key] = imread(kwargs[key] + filename)
+
+        # run training
+        classifier.train(**kwargs_to_pass)
+        continue_training = True
